#
# spec file for package vacuum-im
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sname vacuum
%define rtime 1639054987
%define rhash g0abd5e1
Name:           %{sname}-im
Version:        1.3.0+git%{rtime}.%{rhash}
Release:        1.2
Summary:        Jabber client written with Qt
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            http://www.vacuum-im.org/
Source:         %{name}-r%{rhash}.tar.xz
# PATCH-FEATURE-OPENSUSE paranoia.patch
Patch1:         paranoia.patch
# PATCH-FEATURE-OPENSUSE fix_default_smiles.patch
Patch2:         fix_default_smiles.patch
# Fix sending of type attribute in data forms
# PATCH-FIX-UPSTREAM dataform_submit_type_attr.patch
Patch3:         dataform_submit_type_attr.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  hunspell-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Multimedia-devel
BuildRequires:  libQt5X11Extras-devel
BuildRequires:  libQt5Xml-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  minizip-devel
BuildRequires:  openssl-devel
BuildRequires:  qxtglobalshortcut-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Recommends:     %{name}-lang
Recommends:     %{name}-plugins-spellchecker
%if 0%{?suse_version} > 1320
BuildRequires:  libXss-devel
%else
BuildRequires:  libXScrnSaver-devel
%endif

%description
The core program is just a plugin loader - all functionality is made
available via plugins. This enforces modularity and ensures well defined
component interaction via interfaces.

%define libname libvacuumutils37

%package -n %{libname}
Summary:        Shared library libvacuumutils for Vacuum-IM
Group:          System/Libraries
Conflicts:      libvacuumutils1_7

%description -n %{libname}
This package includes shared libraris needed to work Vacuum-IM program.

%package devel
Summary:        Development files for Vacuum-IM
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description devel
This package includes files needed to develop Vacuum-IM modules.

%package plugins-spellchecker
Summary:        Vacuum-IM spellchecker plugin
Group:          Productivity/Networking/Instant Messenger
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description plugins-spellchecker
Highlights words that may not be spelled correctly.

%package plugins-statistics
Summary:        Vacuum-IM application statistics collection plugin
Group:          Productivity/Networking/Instant Messenger
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description plugins-statistics
This plugin needed to collect application statistics.

%lang_package

%prep
%autosetup -p1 -n vacuum-im

%build
%cmake \
        -DCMAKE_CXX_FLAGS="%{optflags} -std=c++0x"\
        -DGIT_DATE="%{rtime}"\
        -DGIT_HASH="%{rhash}"\
        -DINSTALL_SDK=ON\
        -DINSTALL_APP_DIR=%{name}\
        -DINSTALL_LIB_DIR=%{_lib}\
        -DINSTALL_DOC_DIR=%{_defaultdocdir}\
        -DSPELLCHECKER_BACKEND=HUNSPELL\
        -DFORCE_BUNDLED_MINIZIP=OFF\
        -DNO_WEBKIT=ON\
        -DPLUGIN_adiummessagestyle=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

for size in 16 24 32 48 64 96 128; do
    install -Dpm 0644 resources/menuicons/shared/mainwindowlogo$size.png \
        %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/%{name}.png
done
sed -i "s/^Exec=.*$/Exec=%{name}/;s/^Icon=.*$/Icon=%{name}/" %{buildroot}%{_datadir}/applications/%{sname}.desktop
mv %{buildroot}%{_datadir}/applications/%{sname}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
mv %{buildroot}%{_datadir}/pixmaps/%{sname}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
mv %{buildroot}%{_bindir}/%{sname} %{buildroot}%{_bindir}/%{name}
%suse_update_desktop_file -c %{name} "Vacuum-IM" "Jabber Client" %{name} %{name}.png Network InstantMessaging

%fdupes %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%exclude %{_datadir}/%{name}/translations
%doc %{_defaultdocdir}/%{name}
%{_bindir}/%{name}
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/plugins/libspellchecker.so
%exclude %{_libdir}/%{name}/plugins/libstatistics.so
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/metainfo/vacuum-im.metainfo.xml

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libvacuumutils.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libvacuumutils.so
%{_includedir}/%{name}

%files plugins-spellchecker
%defattr(-,root,root)
%{_libdir}/%{name}/plugins/libspellchecker.so

%files plugins-statistics
%defattr(-,root,root)
%{_libdir}/%{name}/plugins/libstatistics.so

%files lang
%defattr(-,root,root)
%{_datadir}/%{name}/translations
%lang(de) %{_datadir}/%{name}/translations/de/*.qm
%lang(pl) %{_datadir}/%{name}/translations/pl/*.qm
%lang(ru) %{_datadir}/%{name}/translations/ru/*.qm
%lang(uk) %{_datadir}/%{name}/translations/uk/*.qm

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Jul 15 2022 D. Berge <opensuse@navlost.eu>
- update source to revision 0abd5e11dd3e2538b8c47f5a06febedf73ae99ee
  + Don't hide trayicon manually on exit, fix for #965
  + SCRAM-SHA-256/384/512 support. But 384 doesn't work on
    https://lightwitch.org/ for some unknown reasons.
- added patch dataform_submit_type_attr.patch to fix bug with
  XEP-0004 form submission
* Tue Oct 15 2019 Andrey Karepin <egdfree@opensuse.org>
- update source to 9f3952b21b8d3ee1ef76b31abbb027fb21d8ed89
  * support for SCRAM-SHA1 authentication
* Fri Jan 11 2019 Andrey Karepin <egdfree@opensuse.org>
- update source to 3164aec53e8a1da58f328ed13657c654e650636c
  * Do not send country code in xml:lang attribute
  * Allow to change font size in editwidget
  * Fixed RosterView expand state after search
* Sun Feb 11 2018 egdfree@opensuse.org
- use system provided qxtglobalshortcut
- update source to revision 58ad802cdfb34ef920afdfff9a2627dbd837d38d
* Sun Dec 10 2017 jengelh@inai.de
- Update RPM groups and summaries.
* Sun Dec  3 2017 egdfree@opensuse.org
- plugin statistics moved to external package
- deleted fix_cmake_hunspell_found.pach: patch now don't need
- deleted fix_cmake_rules.patch: fixes submitted to upstream
- deleted vacuum-im-gcc6.patch
- added spellchecker plugin to standard plugins
* Sat Jun 18 2016 egdfree@opensuse.org
- add vacuum-im-gcc6.patch to resolve bnc#985094
* Wed Jun 10 2015 egdfree@opensuse.org
- update source to revision c9ea75a
  * fix CMake CMP0022 policy warning
* Tue Jun  9 2015 egdfree@opensuse.org
- update to 1.2.5
  * Fixed automatic activation of notifications
  * Fixed conference entrance detection by status codes
  * The application may fail on changing discovery entity in discovery items window
  * Removed some CAPTCHA validations for compatibility with XEP
  * Fixed truncation nickname to space in the conference /nick command
* Fri Dec  5 2014 egdfree@opensuse.org
- update source to r2464
  * fix possible crash
* Thu Nov  6 2014 egdfree@opensuse.org
- delete fix_utils_version.patch, not needen
* Thu Nov  6 2014 egdfree@opensuse.org
- update source
  * Fixed automatic activation of notifications
  * Fixed conference entrance detection by status codes
* Sun Jan 26 2014 egdfree@opensuse.org
- update to 1.2.4
  * Added workarounds for Facebook XMPP server
  * Fixed same problems with DIGEST-MD5 SASL authentication response
  * Not all messages from server archive were displayed in a view history
    window
  * In a chat window with contact connected through transport all messages
    were displayed as incoming after transport change
  * Fixed problems with editing of a priority of the status in the edit
    status dialog
  * Fixed some possible errors with adding messages in Adium message styles
  * On a double click on the agent in a roster at the same time opened both
    a window of service discovery and a normal message window
  * Fixed rare problems with establishing secure connection with server
* Mon Oct  7 2013 egdfree@opensuse.org
- Change source archive type to xz
- Add patch fix_utils_version.patch to set correcrtly shared libreary name
- update to 1.2.3
  * Added twitter status icons
  * Added the periodic vCard updating
  * Conference name is added to the title of conference settings window
  * Improved the recognition of links in the text
  * Limited the maximum number of recognizable smiles in the message
  * Limited the maximum number of messages (500 messages) in the chat
    window for simple message styles
  * Limited the maximum number of visible chars in the name of the tab in
    message tab window
  * The application will fail if the server terminates the connection before
    the user enters the password
  * Removing of avatars in several selected accounts or contacts was not
    working
  * The application may fail on removing from history active conversation
  * Corrected URL copying from Chrome in to the message entry field
  * Added correct support of CDATA in XML stream parser
  * Fixed admission of letters in contacts search line at a fast typing
  * The notice of a mention in conferences didn't work if the nickname ends
    not with a letter and not with digit
  * Some offline messages may not be stored in the history
  * Fixed endless request of privacy list rules if server returns list
    without rules
  * The application was not completed correctly when current session in OS
    is closing
  * Messages load from history could follow in the chat window in the wrong
    order when they received within one second
  * Restrictions on the maximum size of the file in file archive didn't work
* Fri Mar  8 2013 egdfree@opensuse.org
- update to 1.2.2
  * Full text search in file archive of messages in certain cases worked not correctly
  * Did not work contacts moving from an empty group
  * Proxy authorization in certain cases was not working
* Sun Jan 13 2013 egdfree@opensuse.org
- update to 1.2.1
  * Added skype status icons
  * The animation caching is added
  * Under Linux sounds always are reproduced through aplay call
  * Fixed deletion of history in join conference dialog
  * When editing control of a hotkey instead of empty value value by default was saved
  * The application may fail in some cases after unsuccessful Stanza-session initialization
  * In private chats history of communication are loaded even if the relevant setting has been disabled
  * When changing the nickname in the conference the nickname was not changed in the active conferences menu in the roster window
  * When requesting delivery of unread messages via RemoteControl in the message list fell messages from conferences and received on a different account
  * The behavior of history time removal widgets is corrected and unified in a settings window
  * The saved status messages including about a file transfer, were displayed with incorrect date when loading from history in windows of a usual chat and a private chat of conferences
  * Popup notifications appear now on that monitor where there is the main window
  * The behavior of the main window after Drag&Drop is corrected
  * Popup notifications are not capture input focus in Mac OS X
  * Fixed problem with message appearance in Adium style
* Wed Aug  1 2012 egdfree@opensuse.org
- apply patch
  * The application may fail in some cases after unsuccessful
    Stanza-session initialization
* Tue Jul 31 2012 egdfree@opensuse.org
- update to 1.2.0
  * Added new plugin for notifications about birthdays
  * Added new plugin for loading data from custom types of URLs
  * Added new plugin for exchanging roster contacts
  * Added ability to show a minimized window with the message when notification
    received
  * Added date separators in chat windows and conferences
  * Added ability to remove transpots with their contacts from roster
  * Notice of user activity in the chat duplicated on the chat tab
  * Added new types of notifications and changed the way of their settings
  * Added context menu for tabs in tabwindow
  * Search for contact-list starts automatically, just start typing the word
  * Added ability to rename contacts and groups directly in the contact list
  * Added ability to execute operations on multiple items in roster
  * Notification of request for authorization is now deleted automatically
    in case of confirmation or removal of authorization from another resource
  * Added support for transferring files via SOCKS5 in conferences
  * Added animation support in SimpleMessageStyles and notification pop-ups
  * Added ability to specify environment variables in the resource
  * Improved and optimized work with message archive
  * XML parser did not correctly handle the elements with not declared
    prefixes, which caused to the breaking the connection
  * Fixed bug in Digest-MD5 authorization for which was not possible
    to log on some servers
  * When leaving the hidden conferences also closed the conference on
    non-active tabs
  * In the history view could appear duplicates of conversations
  * Did not correctly handle changes in the participant's nickname
    when new nickname is already used by the same participant but from
    a different resource
  * Incorrectly requested history of communication when connected to
    a server Openfire with plugin Open Archive
  * The first message in the chat may not be saved in the local
    message archive
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Dec 27 2011 egdfree@opensuse.org
- update to 1.1.2
  * Implemented backup settings and restore them automatically
    when the main file is damaged
  * Added support for transferring files via SOCKS5 in conferences
  * In the history view could appear duplicates of conversations
  * Did not correctly handle changes in the participant's
    nickname when new nickname is already used by the same
    participant but from a different resource
  * Fixed crash in Ubuntu 11.10 when alt key is pressed in chat
    window
  * The first message in the chat may not be saved in the local
    message archive
  * Chat dialog icon was not changed after changing the status of
    a contact without changing the text of the status
  * After downloading the new image in the vCard dialog it was
    not displayed in the viewing area
  * Dublicate messages may appear in the history view window
  * The first message in the chat could not be saved in a local
    message archive
  * Messages was incorrectly written into archive if full write
    mode was enabled and message contains xhtml
* Tue Aug 23 2011 egdfree@opensuse.org
- update to 1.1.1
  * Fixed bug with handling stanzas from Google XMPP servers
  * XML parser did not correctly handle the elements with not
    declared prefixes, which caused to the breaking the connection
  * Fixed bug in Digest-MD5 authorization for which was not
    possible to log on some servers
* Tue Mar 15 2011 egdfree@opensuse.org
- update to 1.1.0
  * Added new plugin for remote controlling
  * Added shortcuts support
  * Added support of XEP-0199 - XMPP Ping
  * Changes of contact status and entry/exit of participants in
    conference are stored in the history
  * Added support for arbitrary forms of registration when
    registering an account on the server
  * Server side archive preferences support is not longer required
    for retrieving messages history from server
  * Added support for older versions of the message history protocol,
    when the time of message was stored in seconds from the beginning of
    the conversation
  * Added ability to disable the establishing of unprotected connection to
    the server
  * Contacts list window could be displayed outside the visible screen area
  * Application fails when turn on or off the search in roster
  * It was impossible to set the empty status text
  * At an account the following sign to the global status could be lost after
    reconnection because of breakage of connection with a server
  * Windows with new messages does not always pop up on top of other windows
  * Application may fail on closing options dialog
  * Fixed problems displaying photos in vCard
  * Application may fail on unsuccessful attempt to connect
  * Not all history messages collections with the same start time was displayed
    in hisroty window
  * Recent messages with specified ThreadId could not be deleted from local archive
  * When closing the connection initiated by the server vacuum does not generate an
    error and re-reconnection was not started
  * By transfer of the rest of a file after connection breakage already obtained data
    could be rubbed clean by zero
* Sat Dec 18 2010 egdfree@opensuse.org
- update to 1.0.2
